@@ -186,16 +186,32 @@ uploaded successfully.</source>
         <translation>Soubor &quot;%1&quot;
 nahrán úspěšně.</translation>
     </message>
-    <message>
-        <source>Upload Failure</source>
-        <translation>Nahrávání selhalo</translation>
-    </message>
     <message>
         <source>File &quot;%1&quot;
 failed to upload.</source>
         <translation>Soubor &quot;%1&quot;
 nahrání selhalo.</translation>
     </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AvatarService</name>
@@ -735,10 +751,6 @@ Prosím %1</translation>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation>Soubor &quot;%1&quot; nebyl synchronizován</translation>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation>Funkce není podporována</translation>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation>Soubor %1 již existuje.&lt;br/&gt;Chcete ho přepsat?&lt;br/&gt;&lt;small&gt;(Zvolte Ne pokud ho chcete nahrát s jiným názvem).&lt;/small&gt;</translation>
@@ -751,10 +763,6 @@ Prosím %1</translation>
         <source>Failed to download file: %1</source>
         <translation>Selhalo stažení souboru: %1</translation>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation>Selhalo nahrání souboru: %1</translation>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation>Vyberte soubor k nahrání</translation>
@@ -815,6 +823,34 @@ Prosím %1</translation>
         <source>Create library failed!</source>
         <translation>Vytvoření knihovny selhalo</translation>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -846,6 +882,22 @@ Prosím %1</translation>
         <source>%1 of %2</source>
         <translation>%1 z %2</translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -942,10 +994,6 @@ Prosím %1</translation>
         <source>&amp;Sync this folder</source>
         <translation>&amp;Synchronizovat tento adresář</translation>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -980,6 +1028,22 @@ Prosím %1</translation>
         <source>Unable to cut readonly files</source>
         <translation>Nelze vyjmout soubory pouze pro čtení</translation>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1922,10 +1986,6 @@ Majitel knihovny vyčerpal svůj datový limit.</translation>
         <source>Sync this folder to:</source>
         <translation>Synchronizovat tento adresář s:</translation>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Složka</translation>
@@ -2014,6 +2074,10 @@ Majitel knihovny vyčerpal svůj datový limit.</translation>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
