@@ -38,6 +38,14 @@
         <source>Authorization expired, please re-login</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Failed to remove local repos sync token: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to get repo sync information from server: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AccountSettingsDialog</name>
@@ -136,14 +144,6 @@
         <source>not logged in</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to remove local repos sync token: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Failed to get repo sync information from server: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Form</source>
         <translation type="unfinished"></translation>
@@ -842,6 +842,10 @@ failed to upload.</source>
         <source>Unable to open cache folder</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Search files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -873,6 +877,52 @@ failed to upload.</source>
         <source>%1 of %2</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchModel</name>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Modified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Kind</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileBrowserSearchView</name>
+    <message>
+        <source>&amp;Show in folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show in folder</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -1239,10 +1289,6 @@ Do you like to download your default library?</source>
         <source>Failed to save current account</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Two Factor Authentication</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 Server Address</source>
         <translation type="unfinished"></translation>
@@ -1259,10 +1305,6 @@ Do you like to download your default library?</source>
         <source>Please enter the password</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Enter the two factor authentication token</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Incorrect email or password</source>
         <translation type="unfinished"></translation>
@@ -1331,6 +1373,10 @@ Do you like to download your default library?</source>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Automatic Login</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogoutView</name>
@@ -2960,6 +3006,41 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TwoFactorDialog</name>
+    <message>
+        <source>Enter the two factor authentication token</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Two Factor Authentication</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please enter the two factor authentication token</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dialog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>mText</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>UninstallHelperDialog</name>
     <message>
