@@ -186,16 +186,32 @@ uploaded successfully.</source>
         <translation>Skrá &quot;%1&quot;
 hlaðið upp giftursamlega.</translation>
     </message>
-    <message>
-        <source>Upload Failure</source>
-        <translation>Upphleðsluvilla</translation>
-    </message>
     <message>
         <source>File &quot;%1&quot;
 failed to upload.</source>
         <translation>Skrá &quot;%1&quot;
 mistókst að hlaða upp.</translation>
     </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AvatarService</name>
@@ -734,10 +750,6 @@ mistókst að hlaða upp.</translation>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation>Skrá &quot;%1&quot; hefur ekki verið samstillt</translation>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation>Er ekki virkt</translation>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation>Skrá %1 er þegar til.&lt;br/&gt;Viltu yfirskrifa hana?&lt;/br/&gt;&lt;/small&gt;(Veldu Nei til að hlaða upp með öðru nafni).&lt;/small&gt;</translation>
@@ -750,10 +762,6 @@ mistókst að hlaða upp.</translation>
         <source>Failed to download file: %1</source>
         <translation>Mistókst að niðurhala skrá: %1</translation>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation>Mistókst að upphlaða skrá: %1</translation>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation>Veldu skrá til að hlaða upp</translation>
@@ -814,6 +822,34 @@ mistókst að hlaða upp.</translation>
         <source>Create library failed!</source>
         <translation>Mistókst að búa til safn!</translation>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -845,6 +881,22 @@ mistókst að hlaða upp.</translation>
         <source>%1 of %2</source>
         <translation>%1 af %2</translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -941,10 +993,6 @@ mistókst að hlaða upp.</translation>
         <source>&amp;Sync this folder</source>
         <translation>&amp;Samkeyra þessu skráasafni</translation>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -979,6 +1027,22 @@ mistókst að hlaða upp.</translation>
         <source>Unable to cut readonly files</source>
         <translation>Get ekki klippt skrifvarðar skrár</translation>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1920,10 +1984,6 @@ Geymslupláss eiganda safnsins er orðið fullt.</translation>
         <source>Sync this folder to:</source>
         <translation>Samkeyra þessu skráasafni með:</translation>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Skráasafn</translation>
@@ -2012,6 +2072,10 @@ Geymslupláss eiganda safnsins er orðið fullt.</translation>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
