@@ -186,16 +186,32 @@ uploaded successfully.</source>
         <translation>Filen &quot;%1&quot;
 ble lastet opp.</translation>
     </message>
-    <message>
-        <source>Upload Failure</source>
-        <translation>Opplasting mislyktes</translation>
-    </message>
     <message>
         <source>File &quot;%1&quot;
 failed to upload.</source>
         <translation>Fil &quot;%1&quot;
 opplasting mislyktes</translation>
     </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AvatarService</name>
@@ -734,10 +750,6 @@ opplasting mislyktes</translation>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation>Funksjonen er ikke støttet</translation>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation>Filen %1 eksisterer allerede.&lt;br/&gt;Ønsker du å overskrive den?&lt;br/&gt;&lt;small&gt;(Velg &quot;nei&quot; for laste opp med et annet navn).&lt;/small&gt;</translation>
@@ -750,10 +762,6 @@ opplasting mislyktes</translation>
         <source>Failed to download file: %1</source>
         <translation>Kunne ikke laste ned filen: %1</translation>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation>Kunne ikke laste opp fil: %1</translation>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation>Velg en fil å laste opp</translation>
@@ -814,6 +822,34 @@ opplasting mislyktes</translation>
         <source>Create library failed!</source>
         <translation>Kunne ikke opprette bibliotek!</translation>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -845,6 +881,22 @@ opplasting mislyktes</translation>
         <source>%1 of %2</source>
         <translation>%1 av %2</translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -941,10 +993,6 @@ opplasting mislyktes</translation>
         <source>&amp;Sync this folder</source>
         <translation>&amp;Synkroniser mappen</translation>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -979,6 +1027,22 @@ opplasting mislyktes</translation>
         <source>Unable to cut readonly files</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1915,10 +1979,6 @@ Bibliotekets eier har gått tom for lagringsplass.</translation>
         <source>Sync this folder to:</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation type="unfinished"/>
@@ -2007,6 +2067,10 @@ Bibliotekets eier har gått tom for lagringsplass.</translation>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
