@@ -186,12 +186,28 @@ uploaded successfully.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Upload Failure</source>
+        <source>File &quot;%1&quot;
+failed to upload.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>File &quot;%1&quot;
-failed to upload.</source>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -732,10 +748,6 @@ failed to upload.</source>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation>Functie wordt niet ondersteund</translation>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation>Bestand %1 bestaat reeds.&lt;br/&gt;Wil je dit overschrijven?&lt;br/&gt;&lt;small&gt;(Kies Nee om te uploaden onder een andere naam).&lt;/small&gt;</translation>
@@ -748,10 +760,6 @@ failed to upload.</source>
         <source>Failed to download file: %1</source>
         <translation>Mislukt om bestand te downloaden: %1</translation>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation>Mislukt om bestand te uploaden: %1</translation>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation>Kies een bestand om te uploaden</translation>
@@ -812,6 +820,34 @@ failed to upload.</source>
         <source>Create library failed!</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -843,6 +879,22 @@ failed to upload.</source>
         <source>%1 of %2</source>
         <translation>%1 van %2</translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -939,10 +991,6 @@ failed to upload.</source>
         <source>&amp;Sync this folder</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -976,6 +1024,22 @@ failed to upload.</source>
         <source>Unable to cut readonly files</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1912,10 +1976,6 @@ De opslagruimte van de eigenaar van de bibliotheek is opgebruikt.</translation>
         <source>Sync this folder to:</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation type="unfinished"/>
@@ -2004,6 +2064,10 @@ De opslagruimte van de eigenaar van de bibliotheek is opgebruikt.</translation>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
