@@ -186,16 +186,32 @@ uploaded successfully.</source>
         <translation>Bestand &quot;%1&quot;
 succesvol geüpload.</translation>
     </message>
-    <message>
-        <source>Upload Failure</source>
-        <translation>Upload mislukt</translation>
-    </message>
     <message>
         <source>File &quot;%1&quot;
 failed to upload.</source>
         <translation>Bestand &quot;%1&quot;
 kon niet worden geüpload.</translation>
     </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AvatarService</name>
@@ -733,10 +749,6 @@ kon niet worden geüpload.</translation>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation>Bestand &quot;%1&quot; is niet gesynchroniseerd</translation>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation>Eigenschap wordt niet ondersteund</translation>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation>Bestand %1 bestaat reeds.&lt;br/&gt;Wil je deze overschrijven?&lt;br/&gt;&lt;small&gt;(Kies nee om te uploaden met een alternatieve naam)&lt;/small&gt;</translation>
@@ -749,10 +761,6 @@ kon niet worden geüpload.</translation>
         <source>Failed to download file: %1</source>
         <translation>Kon bestand niet downloaden: %1</translation>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation>Kon bestand niet uploaden: %1</translation>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation>Kies een te uploaden bestand</translation>
@@ -813,6 +821,34 @@ kon niet worden geüpload.</translation>
         <source>Create library failed!</source>
         <translation>Aanmaken bibliotheek mislukt!</translation>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -844,6 +880,22 @@ kon niet worden geüpload.</translation>
         <source>%1 of %2</source>
         <translation>%1 van %2</translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -940,10 +992,6 @@ kon niet worden geüpload.</translation>
         <source>&amp;Sync this folder</source>
         <translation>&amp;Synchroniseer deze map</translation>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -978,6 +1026,22 @@ kon niet worden geüpload.</translation>
         <source>Unable to cut readonly files</source>
         <translation>Kon alleen-lezen bestanden niet knippen</translation>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1919,10 +1983,6 @@ De opslaglimiet van de eigenaar is bereikt.</translation>
         <source>Sync this folder to:</source>
         <translation>Synchroniseer deze map naar:</translation>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Map</translation>
@@ -2011,6 +2071,10 @@ De opslaglimiet van de eigenaar is bereikt.</translation>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
