@@ -186,16 +186,32 @@ uploaded successfully.</source>
         <translation>Dosya &quot;%1&quot;
 başarıyla yüklendi.</translation>
     </message>
-    <message>
-        <source>Upload Failure</source>
-        <translation>Yükleme Hatası</translation>
-    </message>
     <message>
         <source>File &quot;%1&quot;
 failed to upload.</source>
         <translation>Dosya &quot;%1&quot;
 yüklenemedi.</translation>
     </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>AvatarService</name>
@@ -735,10 +751,6 @@ yüklenemedi.</translation>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation>&quot;%1&quot; dosyası senkronize edilmedi</translation>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation>Özellik desteklenmiyor</translation>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation>Dosya %1 zaten var.&lt;br/&gt;Üstüne yazmak ister misiniz?&lt;br/&gt;&lt;small&gt;(Başka bir isim kullanarak yüklemek için Hayır seçin).&lt;/small&gt;</translation>
@@ -751,10 +763,6 @@ yüklenemedi.</translation>
         <source>Failed to download file: %1</source>
         <translation>Dosya indirme başarısız: %1</translation>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation>Dosya yükleme başarsız: </translation>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation>Yüklemek için bir dosya seçin</translation>
@@ -815,6 +823,34 @@ yüklenemedi.</translation>
         <source>Create library failed!</source>
         <translation>Kütüphane oluşturma başarısız!</translation>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -846,6 +882,22 @@ yüklenemedi.</translation>
         <source>%1 of %2</source>
         <translation>%2 de %1</translation>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -942,10 +994,6 @@ yüklenemedi.</translation>
         <source>&amp;Sync this folder</source>
         <translation>&amp;Bu klasörü senkronize et</translation>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -979,6 +1027,22 @@ yüklenemedi.</translation>
         <source>Unable to cut readonly files</source>
         <translation>Salt okunur dosyalar kesilemiyor</translation>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1915,10 +1979,6 @@ Kütüphane sahibinin depolama alanı tükendi.</translation>
         <source>Sync this folder to:</source>
         <translation>Bu klasörü şuraya eşitle:</translation>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Klasör</translation>
@@ -2007,6 +2067,10 @@ Kütüphane sahibinin depolama alanı tükendi.</translation>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
