@@ -186,12 +186,28 @@ uploaded successfully.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Upload Failure</source>
+        <source>File &quot;%1&quot;
+failed to upload.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>File &quot;%1&quot;
-failed to upload.</source>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File does not exist</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The file is locked by %1, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload Failure: %1</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -730,10 +746,6 @@ failed to upload.</source>
         <source>File &quot;%1&quot; haven&apos;t been synced</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Feature not supported</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
         <translation type="unfinished"/>
@@ -746,10 +758,6 @@ failed to upload.</source>
         <source>Failed to download file: %1</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Failed to upload file: %1</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Select a file to upload</source>
         <translation type="unfinished"/>
@@ -810,6 +818,34 @@ failed to upload.</source>
         <source>Create library failed!</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>You do not have permission to upload to this folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Authorization expired</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission Error!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library/Folder not found.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to upload file %1: %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to create cache folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Unable to open cache folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserProgressDialog</name>
@@ -841,6 +877,22 @@ failed to upload.</source>
         <source>%1 of %2</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Retry</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Skip</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Abort</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileNetworkTask</name>
@@ -937,10 +989,6 @@ failed to upload.</source>
         <source>&amp;Sync this folder</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>You do not have permission to upload to this folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>This feature is available in pro version only
 </source>
@@ -974,6 +1022,22 @@ failed to upload.</source>
         <source>Unable to cut readonly files</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Retry Upload</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Delete Local Version</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Version Save As...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Local Cache Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>GetFileTask</name>
@@ -1907,10 +1971,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>Sync this folder to:</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Folder</source>
         <translation type="unfinished"/>
@@ -1999,6 +2059,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>failed to open file cache database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
