@@ -96,6 +96,7 @@ void LoginRequest::requestSuccess(QNetworkReply& reply)
 
     QScopedPointer<json_t, JsonPointerCustomDeleter> json(root);
 
+    QString s2fa_token = reply.rawHeader("X-SEAFILE-S2FA");
     const char* token =
         json_string_value(json_object_get(json.data(), "token"));
     if (token == NULL) {
@@ -104,7 +105,7 @@ void LoginRequest::requestSuccess(QNetworkReply& reply)
         return;
     }
 
-    emit success(token);
+    emit success(token, s2fa_token);
 }
 
 
@@ -805,7 +806,8 @@ void GetLoginTokenRequest::requestSuccess(QNetworkReply& reply)
 FileSearchRequest::FileSearchRequest(const Account& account,
                                      const QString& keyword,
                                      int page,
-                                     int per_page)
+                                     int per_page,
+                                     const QString& repo_id)
     : SeafileApiRequest(account.getAbsoluteUrl(kFileSearchUrl),
                         SeafileApiRequest::METHOD_GET,
                         account.token),
@@ -818,6 +820,7 @@ FileSearchRequest::FileSearchRequest(const Account& account,
     }
     // per_page = 2;
     setUrlParam("per_page", QString::number(per_page));
+    setUrlParam("search_repo", repo_id);
 }
 
 void FileSearchRequest::requestSuccess(QNetworkReply& reply)
