@@ -51,7 +51,7 @@ protected slots:
     void requestSuccess(QNetworkReply& reply);
 
 signals:
-    void success(const QString& token);
+    void success(const QString& token, const QString& s2fa_token);
 
 private:
     Q_DISABLE_COPY(LoginRequest)
@@ -521,7 +521,8 @@ public:
     FileSearchRequest(const Account& account,
                       const QString& keyword,
                       int page = 0,
-                      int per_page = 25);
+                      int per_page = 25,
+                      const QString& repo_id = QString());
     const QString& keyword() const
     {
         return keyword_;
