@@ -41,12 +41,16 @@ enum {
     INDEX_TABLE_VIEW,
     INDEX_LOADING_FAILED_VIEW,
     INDEX_EMPTY_VIEW,
-    INDEX_RELOGIN_VIEW
+    INDEX_RELOGIN_VIEW,
+    INDEX_SEARCH_VIEW
 };
 
 const char *kLoadingFailedLabelName = "LoadingFailedText";
 const int kToolBarIconSize = 24;
 const int kStatusBarIconSize = 20;
+const int kAllPage = 1;
+const int kPerPageCount = 10000;
+const int kSearchBarWidth = 250;
 //const int kStatusCodePasswordNeeded = 400;
 
 void openFile(const QString& path)
@@ -87,7 +91,10 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
       account_(account),
       repo_(repo),
       current_path_(path),
-      current_readonly_(repo_.readonly)
+      current_readonly_(repo_.readonly),
+      search_request_(NULL),
+      search_text_last_modified_(0),
+      has_password_dialog_(false)
 {
     current_lpath_ = current_path_.split('/');
 
@@ -132,20 +139,42 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
     vlayout->setSpacing(0);
     widget->setLayout(vlayout);
 
+    QHBoxLayout *hlayout = new QHBoxLayout;
+    hlayout->setContentsMargins(1, 0, 1, 0);
+    hlayout->setSpacing(0);
+    hlayout->addWidget(toolbar_);
+    hlayout->addWidget(search_toolbar_);
+
+    search_view_ = new FileBrowserSearchView(this);
+    search_view_->setObjectName("searchResult");
+#ifdef Q_OS_MAC
+    search_view_->setAttribute(Qt::WA_MacShowFocusRect, 0);
+#endif
+    search_model_ = new FileBrowserSearchModel(this);
+    search_view_->setModel(search_model_);
+    search_delegate_ = new FileBrowserSearchItemDelegate(this);
+    delete search_view_->itemDelegate();
+    search_view_->setItemDelegate(search_delegate_);
+
     stack_ = new QStackedWidget;
     stack_->insertWidget(INDEX_LOADING_VIEW, loading_view_);
     stack_->insertWidget(INDEX_TABLE_VIEW, table_view_);
     stack_->insertWidget(INDEX_LOADING_FAILED_VIEW, loading_failed_view_);
     stack_->insertWidget(INDEX_EMPTY_VIEW, empty_view_);
     stack_->insertWidget(INDEX_RELOGIN_VIEW, relogin_view_);
+    stack_->insertWidget(INDEX_SEARCH_VIEW, search_view_);
     stack_->setContentsMargins(0, 0, 0, 0);
     stack_->installEventFilter(this);
     stack_->setAcceptDrops(true);
 
-    vlayout->addWidget(toolbar_);
+    vlayout->addLayout(hlayout);
     vlayout->addWidget(stack_);
     vlayout->addWidget(status_bar_);
 
+    search_timer_ = new QTimer(this);
+    connect(search_timer_, SIGNAL(timeout()), this, SLOT(doRealSearch()));
+    search_timer_->start(300);
+
     // this <--> table_view_
     connect(table_view_, SIGNAL(direntClicked(const SeafDirent&)),
             this, SLOT(onDirentClicked(const SeafDirent&)));
@@ -178,6 +207,9 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
     connect(table_view_, SIGNAL(localVersionSaveAs(const SeafDirent&)),
             this, SLOT(onLocalVersionSaveAs(const SeafDirent&)));
 
+    connect(search_view_, SIGNAL(clearSearchBar()),
+            search_bar_, SLOT(clear()));
+
 
     //dirents <--> data_mgr_
     connect(data_mgr_, SIGNAL(getDirentsSuccess(bool, const QList<SeafDirent>&)),
@@ -251,6 +283,8 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
 
 FileBrowserDialog::~FileBrowserDialog()
 {
+    if (search_request_ != NULL)
+        search_request_->deleteLater();
 }
 
 void FileBrowserDialog::init()
@@ -298,6 +332,17 @@ void FileBrowserDialog::createToolBar()
     connect(path_navigator_, SIGNAL(buttonClicked(int)),
             this, SLOT(onNavigatorClick(int)));
 
+    search_toolbar_ = new QToolBar;
+    search_toolbar_->setObjectName("topBar");
+    search_toolbar_->setIconSize(QSize(kToolBarIconSize, kToolBarIconSize));
+    search_toolbar_->setFixedWidth(kSearchBarWidth);
+    search_toolbar_->setStyleSheet("QToolbar { spacing: 0px; }");
+
+    search_bar_ = new SearchBar;
+    search_bar_->setPlaceholderText(tr("Search files"));
+    search_toolbar_->addWidget(search_bar_);
+    connect(search_bar_, SIGNAL(textChanged(const QString&)),
+            this, SLOT(doSearch(const QString&)));
 }
 
 void FileBrowserDialog::createStatusBar()
@@ -353,7 +398,7 @@ void FileBrowserDialog::createStatusBar()
     refresh_button_->setIcon(QIcon(":/images/filebrowser/refresh-gray.png"));
     refresh_button_->setIconSize(QSize(kStatusBarIconSize, kStatusBarIconSize));
     refresh_button_->installEventFilter(this);
-    connect(refresh_button_, SIGNAL(clicked()), this, SLOT(forceRefresh()));
+    connect(refresh_button_, SIGNAL(clicked()), this, SLOT(onRefresh()));
     status_layout_->addWidget(refresh_button_);
 }
 
@@ -451,6 +496,20 @@ bool FileBrowserDialog::eventFilter(QObject *obj, QEvent *event)
     return QObject::eventFilter(obj, event);
 }
 
+void FileBrowserDialog::onRefresh()
+{
+    if (!seafApplet->accountManager()->currentAccount().isValid()) {
+            stack_->setCurrentIndex(INDEX_RELOGIN_VIEW);
+            return;
+    }
+    if (!search_bar_->text().isEmpty()) {
+        search_text_last_modified_ = 1;
+        doRealSearch();
+    } else {
+        forceRefresh();
+    }
+}
+
 void FileBrowserDialog::forceRefresh()
 {
     fetchDirents(true);
@@ -463,17 +522,25 @@ void FileBrowserDialog::fetchDirents()
 
 void FileBrowserDialog::updateFileCount()
 {
-    details_label_->setText(tr("%1 items").arg(table_model_->rowCount()));
+    int row_count = 0;
+    if (stack_->currentIndex() == INDEX_TABLE_VIEW)
+        row_count = table_model_->rowCount();
+    if (stack_->currentIndex() == INDEX_SEARCH_VIEW)
+        row_count = search_model_->rowCount();
+
+    details_label_->setText(tr("%1 items").arg(row_count));
 }
 
 void FileBrowserDialog::fetchDirents(bool force_refresh)
 {
-    if (repo_.encrypted && !data_mgr_->isRepoPasswordSet(repo_.id)) {
+    if (!has_password_dialog_ && repo_.encrypted && !data_mgr_->isRepoPasswordSet(repo_.id)) {
+        has_password_dialog_ = true;
         SetRepoPasswordDialog password_dialog(repo_, this);
         if (password_dialog.exec() != QDialog::Accepted) {
             reject();
             return;
         } else {
+            has_password_dialog_ = false;
             data_mgr_->setRepoPasswordSet(repo_.id, password_dialog.password());
         }
     }
@@ -540,7 +607,7 @@ void FileBrowserDialog::createLoadingFailedView()
     loading_failed_view_->setAlignment(Qt::AlignCenter);
 
     connect(loading_failed_view_, SIGNAL(linkActivated(const QString&)),
-            this, SLOT(forceRefresh()));
+            this, SLOT(onRefresh()));
 }
 
 void FileBrowserDialog::createEmptyView()
@@ -951,7 +1018,7 @@ void FileBrowserDialog::onUploadFinished(bool success)
       names.push_back(task->name());
       local_path = QFileInfo(local_path).absolutePath();
     } else {
-      names = multi_task->names();
+      names = multi_task->successfulNames();
       local_path = QFileInfo(local_path).absoluteFilePath();
     }
 
@@ -984,6 +1051,10 @@ void FileBrowserDialog::onUploadFinished(bool success)
 bool FileBrowserDialog::setPasswordAndRetry(FileNetworkTask *task)
 {
     if (task->httpErrorCode() == 400) {
+        if (has_password_dialog_) {
+            return true;
+        }
+        has_password_dialog_ = true;
         SetRepoPasswordDialog password_dialog(repo_, this);
         if (password_dialog.exec() == QDialog::Accepted) {
             if (task->type() == FileNetworkTask::Download)
@@ -1470,3 +1541,62 @@ void FileBrowserDialog::onAccountInfoUpdated()
 {
     forceRefresh();
 }
+
+void FileBrowserDialog::doSearch(const QString &keyword)
+{
+    // make it search utf-8 charcters
+    if (keyword.toUtf8().size() < 3) {
+        stack_->setCurrentIndex(INDEX_TABLE_VIEW);
+        updateFileCount();
+        return;
+    }
+
+    // save for doRealSearch
+    search_text_last_modified_ = QDateTime::currentMSecsSinceEpoch();
+}
+
+void FileBrowserDialog::doRealSearch()
+{
+    // not modified
+    if (search_text_last_modified_ == 0)
+        return;
+    // modified too fast
+    if (QDateTime::currentMSecsSinceEpoch() - search_text_last_modified_ <= 300)
+        return;
+
+    if (!account_.isValid())
+        return;
+
+    if (search_request_) {
+        // search_request_->abort();
+        search_request_->deleteLater();
+        search_request_ = NULL;
+    }
+
+    stack_->setCurrentIndex(INDEX_LOADING_VIEW);
+
+    search_request_ = new FileSearchRequest(account_, search_bar_->text(), kAllPage, kPerPageCount, repo_.id);
+    connect(search_request_, SIGNAL(success(const std::vector<FileSearchResult>&, bool, bool)),
+            this, SLOT(onSearchSuccess(const std::vector<FileSearchResult>&, bool, bool)));
+    connect(search_request_, SIGNAL(failed(const ApiError&)),
+            this, SLOT(onSearchFailed(const ApiError&)));
+
+    search_request_->send();
+
+    // reset
+    search_text_last_modified_ = 0;
+}
+
+void FileBrowserDialog::onSearchSuccess(const std::vector<FileSearchResult>& results,
+                                bool is_loading_more,
+                                bool has_more)
+{
+    search_model_->setSearchResult(results);
+    stack_->setCurrentIndex(INDEX_SEARCH_VIEW);
+    updateFileCount();
+}
+
+void FileBrowserDialog::onSearchFailed(const ApiError& error)
+{
+    stack_->setCurrentIndex(INDEX_LOADING_FAILED_VIEW);
+}
