@@ -6,6 +6,8 @@
 
 #include "account.h"
 #include "api/server-repo.h"
+#include "file-browser-search-tab.h"
+#include "ui/search-bar.h"
 
 class QToolBar;
 class QToolButton;
@@ -29,6 +31,13 @@ class DataManager;
 class FileNetworkTask;
 class FileBrowserManager;
 
+class SearchBar;
+class FileBrowserSearchItemDelegate;
+class FileBrowserSearchView;
+class FileBrowserSearchModel;
+struct FileSearchResult;
+class FileSearchRequest;
+
 /**
  * This dialog is used when the user clicks on a repo not synced yet.
  *
@@ -67,7 +76,7 @@ private slots:
     void fetchDirents();
     void onDirentClicked(const SeafDirent& dirent);
     void onDirentSaveAs(const QList<const SeafDirent*>& dirents);
-    void forceRefresh();
+    void onRefresh();
     void goForward();
     void goBackward();
     void goHome();
@@ -131,6 +140,14 @@ private slots:
 
     void onAccountInfoUpdated();
 
+    //search
+    void doSearch(const QString& keyword);
+    void doRealSearch();
+    void onSearchSuccess(const std::vector<FileSearchResult>& results,
+                         bool is_loading_more,
+                         bool has_more);
+    void onSearchFailed(const ApiError& error);
+
 private:
     Q_DISABLE_COPY(FileBrowserDialog)
 
@@ -158,6 +175,8 @@ private:
 
     void updateFileCount();
 
+    void forceRefresh();
+
     bool setPasswordAndRetry(FileNetworkTask *task);
 
     bool eventFilter(QObject *obj, QEvent *event);
@@ -173,6 +192,11 @@ private:
     QStack<QString> forward_history_;
     QStack<QString> backward_history_;
 
+    //search
+    QTimer *search_timer_;
+    FileSearchRequest *search_request_;
+    qint64 search_text_last_modified_;
+
     // copy-paste related items between different instances of FileBrowserDialog
     static QStringList file_names_to_be_pasted_;
     static QString dir_path_to_be_pasted_from_;
@@ -187,6 +211,7 @@ private:
 
     // top toolbar
     QToolBar *toolbar_;
+    QToolBar *search_toolbar_;
     QToolButton *backward_button_;
     QToolButton *forward_button_;
     QButtonGroup *path_navigator_;
@@ -213,7 +238,15 @@ private:
     FileTableView *table_view_;
     FileTableModel *table_model_;
 
+    SearchBar *search_bar_;
+    FileBrowserSearchItemDelegate *search_delegate_;
+    FileBrowserSearchView *search_view_;
+    FileBrowserSearchModel *search_model_;
+
     DataManager *data_mgr_;
+
+    // Avoid showing multiple SetRepoPasswordDialog
+    bool has_password_dialog_;
 };
 
 #endif  // SEAFILE_CLIENT_FILE_BROWSER_DIALOG_H
