@@ -35,6 +35,8 @@ const int kFileNameColumnWidth = 200;
 const int kExtraPadding = 30;
 const int kDefaultColumnSum = kFileNameColumnWidth + kDefaultColumnWidth * 3 + kExtraPadding;
 const int kLockIconSize = 16;
+const int kFileStatusIconSize = 16;
+const int kMarginBetweenFileNameAndStatusIcon = 5;
 
 const int kRefreshProgressInterval = 1000;
 
@@ -54,7 +56,27 @@ enum {
 };
 
 const int DirentLockStatusRole = Qt::UserRole + 1;
-const int DirentLockOwnerRoler = Qt::UserRole + 2;
+const int DirentLockOwnerRole = Qt::UserRole + 2;
+const int DirentCacheStatusRole = Qt::UserRole + 3;
+
+QIcon getFileStatusIcon(AutoUpdateManager::FileStatus file_status)
+{
+    QString icon;
+    const QString prefix = ":/images/sync/";
+    switch (file_status) {
+        case AutoUpdateManager::SYNCED:
+            icon = "status-done";
+            break;
+        case AutoUpdateManager::UPLOADING:
+            icon = "status-syncing";
+            break;
+        case AutoUpdateManager::NOT_SYNCED:
+            icon = "exclamation";
+            break;
+    }
+
+    return QIcon(prefix + icon + ".png");
+}
 
 } // namespace
 
@@ -147,9 +169,29 @@ void FileTableViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem
                    size - QSize(kColumnIconSize + kMarginLeft, 0));
         painter->setPen(kFileNameFontColor);
         painter->setFont(font);
-        painter->drawText(rect,
-                          Qt::AlignLeft | Qt::AlignVCenter | Qt::TextSingleLine,
-                          fitTextToWidth(text, option.font, rect.width() - 20));
+        painter->drawText(
+            rect,
+            Qt::AlignLeft | Qt::AlignVCenter | Qt::TextSingleLine,
+            fitTextToWidth(
+                text,
+                option.font,
+                rect.width() - kMarginBetweenFileNameAndStatusIcon - kFileStatusIconSize - 5));
+
+        QVariant file_status_v = model->data(index, DirentCacheStatusRole);
+        if (!file_status_v.isNull()) {
+            AutoUpdateManager::FileStatus file_status = (AutoUpdateManager::FileStatus)file_status_v.toInt();
+            // printf ("file status is %d\n", (int)file_status);
+
+            QPoint status_icon_pos = option.rect.topRight() - QPoint(kFileStatusIconSize + 3, 0);
+            status_icon_pos.setY(option.rect.center().y() - (kFileStatusIconSize / 2));
+            QRect status_icon_rect(status_icon_pos, QSize(kFileStatusIconSize, kFileStatusIconSize));
+
+            QPixmap status_icon_pixmap = getFileStatusIcon(file_status).pixmap(status_icon_rect.size());
+
+            painter->save();
+            painter->drawPixmap(status_icon_rect, status_icon_pixmap);
+            painter->restore();
+        }
     }
     break;
     case FILE_COLUMN_SIZE:
@@ -235,7 +277,6 @@ FileTableView::FileTableView(QWidget *parent)
     setSelectionMode(QAbstractItemView::ExtendedSelection);
 
     setMouseTracking(true);
-    setAcceptDrops(true);
     setDragDropMode(QAbstractItemView::DropOnly);
     setItemDelegate(new FileTableViewDelegate(this));
 
@@ -289,6 +330,15 @@ void FileTableView::setupContextMenu()
     connect(parent_, SIGNAL(aboutToClose()),
             context_menu_, SLOT(close()));
 
+    retry_upload_cached_file_action_ = new QAction(tr("Retry Upload"), this);
+    connect(retry_upload_cached_file_action_, SIGNAL(triggered()),
+            this, SLOT(onRetryUploadCachedFile()));
+    delete_local_version_action_ = new QAction(tr("Delete Local Version"), this);
+    connect(delete_local_version_action_, SIGNAL(triggered()),
+            this, SLOT(onDeleteLocalVersion()));
+    local_version_saveas_action_ = new QAction(tr("Local Version Save As..."), this);
+    connect(local_version_saveas_action_, SIGNAL(triggered()),
+            this, SLOT(onLocalVersionSaveAs()));
     saveas_action_ = new QAction(tr("&Save As..."), this);
     connect(saveas_action_, SIGNAL(triggered()),
             this, SLOT(onSaveAs()));
@@ -369,6 +419,14 @@ void FileTableView::setupContextMenu()
         sync_subdirectory_action_->setToolTip(tr("This feature is available in pro version only\n"));
     }
 
+    open_local_cache_folder_action_ = new QAction(tr("Open Local Cache Folder"), this);
+    connect(open_local_cache_folder_action_, SIGNAL(triggered()),
+                this, SLOT(onOpenLocalCacheFolder()));
+
+    context_menu_->addAction(retry_upload_cached_file_action_);
+    context_menu_->addAction(delete_local_version_action_);
+    context_menu_->addAction(local_version_saveas_action_);
+    context_menu_->addSeparator();
     context_menu_->addAction(saveas_action_);
     context_menu_->addAction(share_action_);
     context_menu_->addAction(share_seafile_action_);
@@ -386,7 +444,12 @@ void FileTableView::setupContextMenu()
     // context_menu_->addAction(update_action_);
     context_menu_->addAction(cancel_download_action_);
     context_menu_->addAction(sync_subdirectory_action_);
+    context_menu_->addSeparator();
+    context_menu_->addAction(open_local_cache_folder_action_);
 
+    this->addAction(retry_upload_cached_file_action_);
+    this->addAction(delete_local_version_action_);
+    this->addAction(local_version_saveas_action_);
     this->addAction(saveas_action_);
     this->addAction(share_action_);
     this->addAction(share_seafile_action_);
@@ -399,6 +462,7 @@ void FileTableView::setupContextMenu()
     // this->addAction(update_action_);
     this->addAction(cancel_download_action_);
     this->addAction(sync_subdirectory_action_);
+    this->addAction(open_local_cache_folder_action_);
 
     paste_only_menu_ = new QMenu(this);
     paste_only_menu_->addAction(paste_action_);
@@ -410,12 +474,25 @@ void FileTableView::contextMenuEvent(QContextMenuEvent *event)
     const QModelIndex proxy_index = indexAt(position);
     position = viewport()->mapToGlobal(position);
 
+    retry_upload_cached_file_action_->setVisible(false);
+    delete_local_version_action_->setVisible(false);
+    local_version_saveas_action_->setVisible(false);
+    open_local_cache_folder_action_->setEnabled(false);
+
+    //
+    // paste_action shows only if there are files in the clipboard
+    // and is enabled only if it comes from the same account
+    //
     paste_action_->setVisible(parent_->hasFilesToBePasted());
 
     //
     // show paste only menu for no items
     // paste-dedicated menu
     //
+    paste_action_->setEnabled(!parent_->current_readonly_ &&
+                              parent_->account_to_be_pasted_from_ ==
+                                  parent_->account_ &&
+                              parent_->hasFilesToBePasted());
     if (!proxy_index.isValid()) {
         if (parent_->hasFilesToBePasted()) {
             paste_only_menu_->exec(position);
@@ -423,15 +500,6 @@ void FileTableView::contextMenuEvent(QContextMenuEvent *event)
         return;
     }
 
-    //
-    // paste_action shows only if there are files in the clipboard
-    // and is enabled only if it comes from the same account
-    //
-    paste_action_->setVisible(parent_->hasFilesToBePasted());
-    paste_action_->setEnabled(!parent_->current_readonly_ &&
-                              parent_->account_to_be_pasted_from_ ==
-                                  parent_->account_ &&
-                              parent_->hasFilesToBePasted());
     // printf ("paste action enabled: %s\n", paste_action_->isEnabled() ? "true": "false");
 
     //
@@ -531,11 +599,20 @@ void FileTableView::contextMenuEvent(QContextMenuEvent *event)
         if (item_->locked_by_me) {
             lock_action_->setText(tr("Un&lock"));
             lock_action_->setVisible(true);
+            move_action_->setEnabled(true);
+            remove_action_->setEnabled(true);
+            rename_action_->setEnabled(true);
         } else if (item_->is_locked || item_->readonly) {
             lock_action_->setVisible(false);
+            move_action_->setEnabled(false);
+            remove_action_->setEnabled(false);
+            rename_action_->setEnabled(false);
         } else {
             lock_action_->setText(tr("&Lock"));
             lock_action_->setVisible(true);
+            move_action_->setEnabled(true);
+            remove_action_->setEnabled(true);
+            rename_action_->setEnabled(true);
         }
 
         // update_action_->setVisible(true);
@@ -557,6 +634,20 @@ void FileTableView::contextMenuEvent(QContextMenuEvent *event)
         share_to_group_action_->setVisible(false);
     }
 
+    QVariant file_status_v = source_model_->data(index, DirentCacheStatusRole);
+    AutoUpdateManager::FileStatus file_status = (AutoUpdateManager::FileStatus)file_status_v.toInt();
+    if (file_status == AutoUpdateManager::NOT_SYNCED) {
+        retry_upload_cached_file_action_->setVisible(true);
+        delete_local_version_action_->setVisible(true);
+        local_version_saveas_action_->setVisible(true);
+    }
+
+    QString localpath = DataManager::getLocalCacheFilePath(
+        parent_->repo_.id, ::pathJoin(parent_->current_path_, dirent->name));
+    if (QFileInfo(localpath).exists()) {
+        open_local_cache_folder_action_->setEnabled(true);
+    }
+
     context_menu_->exec(position); // synchronously
 
     //
@@ -581,6 +672,34 @@ void FileTableView::onItemDoubleClicked(const QModelIndex& index)
     emit direntClicked(*dirent);
 }
 
+void FileTableView::onRetryUploadCachedFile()
+{
+    const SeafDirent *dirent = getSelectedItemFromSource();
+    parent_->onGetDirentReupload(*dirent);
+}
+
+void FileTableView::onDeleteLocalVersion()
+{
+    const SeafDirent *dirent = getSelectedItemFromSource();
+
+    if (dirent == NULL) {
+        return;
+    }
+
+    emit deleteLocalVersion(*dirent);
+}
+
+void FileTableView::onLocalVersionSaveAs()
+{
+    const SeafDirent *dirent = getSelectedItemFromSource();
+
+    if (dirent == NULL) {
+        return;
+    }
+
+    emit localVersionSaveAs(*dirent);
+}
+
 void FileTableView::onSaveAs()
 {
     if (item_ == NULL) {
@@ -765,57 +884,9 @@ void FileTableView::onSyncSubdirectory()
         emit syncSubdirectory(item_->name);
 }
 
-void FileTableView::dropEvent(QDropEvent *event)
+void FileTableView::onOpenLocalCacheFolder()
 {
-    // only handle external source currently
-    if(event->source() != NULL)
-        return;
-
-    QList<QUrl> urls = event->mimeData()->urls();
-
-    if(urls.isEmpty())
-        return;
-
-    QStringList paths;
-    Q_FOREACH(const QUrl& url, urls)
-    {
-        QString path = url.toLocalFile();
-#if defined(Q_OS_MAC) && (QT_VERSION <= QT_VERSION_CHECK(5, 4, 0))
-        path = utils::mac::fix_file_id_url(path);
-#endif
-
-        if(path.isEmpty())
-            continue;
-        paths.push_back(path);
-    }
-
-    event->accept();
-
-    if (parent_->current_readonly_) {
-        seafApplet->warningBox(tr("You do not have permission to upload to this folder"), this);
-    } else {
-        emit dropFile(paths);
-    }
-}
-
-void FileTableView::dragMoveEvent(QDragMoveEvent *event)
-{
-    // this is needed
-    event->accept();
-}
-
-void FileTableView::dragEnterEvent(QDragEnterEvent *event)
-{
-    // only handle external source currently
-    if(event->source() != NULL)
-        return;
-
-    // Otherwise it might be a MoveAction which is unacceptable
-    event->setDropAction(Qt::CopyAction);
-
-    // trivial check
-    if(event->mimeData()->hasFormat("text/uri-list"))
-        event->accept();
+    parent_->onOpenLocalCacheFolder();
 }
 
 void FileTableView::resizeEvent(QResizeEvent *event)
@@ -832,6 +903,8 @@ FileTableModel::FileTableModel(QObject *parent)
     task_progress_timer_ = new QTimer(this);
     connect(task_progress_timer_, SIGNAL(timeout()),
             this, SLOT(updateDownloadInfo()));
+    connect(task_progress_timer_, SIGNAL(timeout()),
+            this, SLOT(updateFileCacheStatus()));
     connect(ThumbnailService::instance(), SIGNAL(thumbnailUpdated(const QPixmap&, const QString&)),
             this, SLOT(updateThumbnail(const QPixmap &, const QString&)));
     task_progress_timer_->start(kRefreshProgressInterval);
@@ -842,7 +915,12 @@ void FileTableModel::setDirents(const QList<SeafDirent>& dirents)
     beginResetModel();
     dirents_ = dirents;
     progresses_.clear();
+    file_cache_statuses_.clear();
     endResetModel();
+
+    updateFileCacheStatus();
+    updateDownloadInfo();
+    task_progress_timer_->start();
 }
 
 int FileTableModel::rowCount(const QModelIndex& parent) const
@@ -915,7 +993,7 @@ QVariant FileTableModel::data(const QModelIndex & index, int role) const
             return NOT_LOCKED;
     }
 
-    if (role == DirentLockOwnerRoler && column == FILE_COLUMN_NAME) {
+    if (role == DirentLockOwnerRole && column == FILE_COLUMN_NAME) {
         return dirent.lock_owner;
     }
 
@@ -923,6 +1001,12 @@ QVariant FileTableModel::data(const QModelIndex & index, int role) const
         return tr("locked by %1").arg(dirent.getLockOwnerDisplayString());
     }
 
+    if (role == DirentCacheStatusRole) {
+        return file_cache_statuses_.contains(dirent.name)
+                   ? (int)file_cache_statuses_[dirent.name]
+                   : QVariant();
+    }
+
     if (role != Qt::DisplayRole) {
         return QVariant();
     }
@@ -1076,6 +1160,39 @@ void FileTableModel::updateDownloadInfo()
                      index(dirents_.size() - 1 , FILE_COLUMN_SIZE));
 }
 
+
+void FileTableModel::updateFileCacheStatus()
+{
+    if (dirents_.empty())
+        return;
+
+    FileBrowserDialog *dialog = (FileBrowserDialog *)(QObject::parent());
+    QHash<QString, AutoUpdateManager::FileStatus> new_statues =
+        AutoUpdateManager::instance()->getFileStatusForDirectory(
+            dialog->account_.getSignature(),
+            dialog->repo_.id,
+            dialog->current_path_,
+            dirents_);
+
+    if (new_statues == file_cache_statuses_) {
+        return;
+    }
+
+    for (int pos = 0; pos != dirents_.size() ; pos++) {
+        const QString& name = dirents_[pos].name;
+        int new_status = new_statues.contains(name) ? (int)new_statues[name] : -1;
+        int old_status = file_cache_statuses_.contains(name) ? (int)file_cache_statuses_[name] : -1;
+        if (new_status != old_status) {
+            emit dataChanged(index(pos, FILE_COLUMN_NAME), index(pos , FILE_COLUMN_NAME));
+        }
+    }
+
+    file_cache_statuses_ = new_statues;
+    // printf ("repainting when file cache status is changed\n");
+    // emit dataChanged(index(0, FILE_COLUMN_NAME),
+    //                  index(dirents_.size() - 1 , FILE_COLUMN_NAME));
+}
+
 void FileTableModel::updateThumbnail(const QPixmap& thumbnail, const QString& path)
 {
     const QString name = QFileInfo(path).fileName();
