@@ -99,11 +99,13 @@ public slots:
 
 signals:
     void progressUpdate(qint64 transferred, qint64 total);
+    void nameUpdate(QString current_name);
     void finished(bool success);
     void retried(int retry_count);
 
 protected slots:
     void onFileServerTaskProgressUpdate(qint64 transferred, qint64 total);
+    void onFileServerTaskNameUpdate(QString current_name);
     virtual void onLinkGet(const QString& link);
     virtual void onGetLinkFailed(const ApiError& error);
     virtual void startFileServerTask(const QString& link);
@@ -178,11 +180,29 @@ public:
     // duplicate a task same with the old one, excluding its internal stage
     FileUploadTask(const FileUploadTask& rhs);
 
+    // When a file fails to upload, we ask the user to confirm what he wants to
+    // do: retry/skip/abort.
+    //
+    //  - abort: task->cancel()
+    //  - retry: task->continueWithFailedFile(true)
+    //  - skip: task->continueWithFailedFile(false)
+    void continueWithFailedFile(bool retry);
+
+    // Accessors
     TaskType type() const { return Upload; }
     const QString& name() const { return name_; }
     bool useUpload() const { return use_upload_; }
 
+signals:
+    // This signal is meant to be listened by the file progress dialog.
+    void oneFileFailed(const QString& filename, bool single_file);
+
+protected slots:
+    // Here
+    virtual void onOneFileFailed(const QString& filename, bool single_file);
+
 protected:
+    virtual void startFileServerTask(const QString& link);
     void createFileServerTask(const QString& link);
     void createGetLinkRequest();
 
@@ -206,6 +226,7 @@ public:
                            bool use_upload);
 
     const QStringList& names() const { return names_; }
+    const QStringList& successfulNames();
 
 protected:
     void createFileServerTask(const QString& link);
@@ -255,6 +276,8 @@ public:
                    const QString& local_path);
     virtual ~FileServerTask();
 
+    virtual void continueWithFailedFile(bool retry) {};
+
     // accessors
     const FileNetworkTask::TaskError& error() const { return error_; }
     const QString& errorString() const { return error_string_; }
@@ -262,14 +285,19 @@ public:
     virtual const QString& oid() const { return oid_; }
     int retryCount() const { return retry_count_; }
     const QString& failedPath() const { return failed_path_; }
+    bool canceled() const { return canceled_; }
 
     static void resetQNAM();
 
 signals:
     void progressUpdate(qint64 transferred, qint64 total);
+    void nameUpdate(QString current_name);
     void finished(bool success);
     void retried(int retry_count);
 
+signals:
+    void oneFileFailed(const QString& filename, bool single_file);
+
 public slots:
     void start();
     virtual void cancel();
@@ -355,6 +383,10 @@ public:
     ~PostFilesTask();
     int currentNum();
 
+    const QStringList& successfulNames() const { return successful_names_; }
+
+    void continueWithFailedFile(bool retry);
+
 protected:
     void prepare();
     void sendRequest();
@@ -374,6 +406,9 @@ private:
     const QString name_;
     QList<qint64> file_sizes_;
     const QStringList names_;
+    QStringList successful_names_;
+
+    QString current_name_;
 
     QScopedPointer<ReliablePostFileTask, doDeleteLater<ReliablePostFileTask> > task_;
     int current_num_;
