@@ -73,6 +73,7 @@ PrivateShareDialog::PrivateShareDialog(const Account& account,
 #endif
 
     username_input_ = new QLineEdit(this);
+    username_input_->setObjectName("mUsernameInputBar");
     groupname_input_ = new QComboBox(this);
 
     mInputStack->insertWidget(INDEX_USER_NAME, username_input_);
@@ -93,7 +94,7 @@ PrivateShareDialog::PrivateShareDialog(const Account& account,
     }
     else {
         mInputStack->setCurrentIndex(INDEX_USER_NAME);
-        username_input_->setPlaceholderText(tr("Enter the email address"));
+        username_input_->setPlaceholderText(tr("Enter user name or email address"));
     }
     mOkBtn->setEnabled(false);
     mPermission->setCurrentIndex(0);
@@ -146,6 +147,7 @@ void PrivateShareDialog::createTable()
     vlayout->insertWidget(1, table_);
 
     table_->setItemDelegate(new SharedItemDelegate(this));
+    table_->setEditTriggers(QAbstractItemView::SelectedClicked);
 
     // Overloaded signal for updating group share.
     connect(model_, SIGNAL(updateShareItem(int, SharePermission)), this,
@@ -358,8 +360,8 @@ bool PrivateShareDialog::validateInputs()
 {
     QString name = lineEdit()->text().trimmed();
     if (name.isEmpty()) {
-        showWarning(to_group_ ? tr("Please enter the username")
-                              : tr("Please enter the group name"));
+        showWarning(to_group_ ? tr("Please enter the group name")
+                              : tr("Please enter the username"));
         return false;
     }
 
@@ -388,6 +390,11 @@ bool PrivateShareDialog::validateInputs()
     }
     else {
         const SeafileUser& user = user_name_completer_->currentSelectedUser();
+        if (!user.isValid()) {
+            showWarning(tr("Please enter the username"));
+            return false;
+        }
+
         if (model_->shareExists(user)) {
             UserShareInfo info = model_->shareInfo(user);
             if (info.permission == permission) {
@@ -412,7 +419,10 @@ SeafileGroup PrivateShareDialog::findGroup(const QString& name)
 
 void PrivateShareDialog::onUserNameChoosed()
 {
-    mOkBtn->setEnabled(true);
+    const SeafileUser& user = user_name_completer_->currentSelectedUser();
+    if (user.isValid()) {
+        mOkBtn->setEnabled(true);
+    }
 }
 
 void PrivateShareDialog::onOkBtnClicked()
@@ -599,7 +609,7 @@ QVariant SharedItemsTableModel::data(const QModelIndex& index, int role) const
 
     if (role == Qt::ToolTipRole) {
         if (column == COLUMN_PERMISSION) {
-            return tr("Double click to edit");
+            return tr("Click to edit");
         }
         else {
             if (isGroupShare()) {
