@@ -88,17 +88,7 @@ void SearchResultItemDelegate::paint(QPainter *painter,
     painter->restore();
 
     QIcon icon = model->data(index, Qt::DecorationRole).value<QIcon>();
-    // get the device pixel radio from current painter device
-    int scale_factor = 1;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-    scale_factor = painter->device()->devicePixelRatio();
-#endif // QT5
-    QPixmap pixmap(icon.pixmap(QSize(kFileIconWidth, kFileIconHeight) * scale_factor));
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-    if (pixmap.size() != QSize(kFileIconWidth, kFileIconHeight))
-        pixmap.setDevicePixelRatio(scale_factor);
-#endif // QT5
-
+    QPixmap pixmap(icon.pixmap(QSize(kFileIconWidth, kFileIconHeight)));
     //
     // paint file icon
     //
